diff config/environments/test.rb @ 72:257910c60eb3

Rails 5 \o/
author nanaya <me@myconan.net>
date Fri, 13 May 2016 04:32:21 +0900
parents 3f419d621b06
children f67f3ad50270
line wrap: on
line diff
--- a/config/environments/test.rb	Tue Mar 01 16:34:29 2016 +0900
+++ b/config/environments/test.rb	Fri May 13 04:32:21 2016 +0900
@@ -12,9 +12,11 @@
   # preloads Rails for running tests, you may have to set it to true.
   config.eager_load = false
 
-  # Configure static asset server for tests with Cache-Control for performance.
-  config.serve_static_files = true
-  config.static_cache_control = "public, max-age=3600"
+  # Configure public file server for tests with Cache-Control for performance.
+  config.public_file_server.enabled = true
+  config.public_file_server.headers = {
+    "Cache-Control" => "public, max-age=3600"
+  }
 
   # Show full error reports and disable caching.
   config.consider_all_requests_local       = true
@@ -25,6 +27,7 @@
 
   # Disable request forgery protection in test environment.
   config.action_controller.allow_forgery_protection = false
+  # config.action_mailer.perform_caching = false
 
   # Tell Action Mailer not to deliver emails to the real world.
   # The :test delivery method accumulates sent emails in the
@@ -36,6 +39,4 @@
 
   # Raises error for missing translations
   # config.action_view.raise_on_missing_translations = true
-
-  config.active_support.test_order = :random
 end